package cn.wise.sc.cement.business.service.impl;



import cn.wise.sc.cement.business.entity.EntityEnclosure;
import cn.wise.sc.cement.business.entity.TeamGroup;
import cn.wise.sc.cement.business.mapper.EntityEnclosureMapper;
import cn.wise.sc.cement.business.mapper.TeamGroupMapper;
import cn.wise.sc.cement.business.mapper.TeamMapper;
import cn.wise.sc.cement.business.model.BaseResponse;
import cn.wise.sc.cement.business.model.query.EnclosureQuery;
import cn.wise.sc.cement.business.service.IEntityEnclosureService;
import cn.wise.sc.cement.business.util.CheckCountUtil;
import com.alibaba.fastjson.JSONArray;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import io.swagger.models.auth.In;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.*;

@Service
public class CommonServiceImpl {

	@Resource
	private EntityEnclosureMapper entityEnclosureMapper;
	@Autowired
	private IEntityEnclosureService entityEnclosureService;
	@Resource
	private TeamMapper teamMapper;

	/**
	 * 生成编号
	 * @param prefix 编号前缀:  申请编号SQ
	 * @param counts 当天申请数量 生成的编号+1
	 * @return
	 */
	public String createNo(String prefix, int counts){
		SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd");//注意月份是MM
		String date = sdf.format(new Date());
		int nextNo = counts+1;
		String tailNo = counts==0?"00"+nextNo:(counts<10?"00"+nextNo:(counts<100?"0"+nextNo:String.valueOf(nextNo)));
		String applyNo = prefix+date+tailNo;
		return applyNo;
	}

	/**
	 * 生成平行样编号
	 * @param cementCode
	 * @return
	 */
	public String createParallelCode(String cementCode){
		String[] cementCodes = cementCode.split("-");
		Integer counts = Integer.parseInt(cementCodes[1])+1;
		String tailNo = counts<10?("000"+counts):
				counts<100?("00"+counts):
						counts<1000?("000"+counts):
								String.valueOf(counts);
		String resultCode = cementCodes[0]+"-"+tailNo;
		return resultCode;
	}

	/**
	 * 获取本所编号的Integer类型
	 * @param cementCode
	 * @return
	 */
	public Integer getIntegerCode(String cementCode){
		String[] cementCodes = cementCode.split("-");
		Integer counts = Integer.parseInt(cementCodes[1]);
		return counts;
	}

	/**
	 * 获取本所编号年份的Integer类型
	 * @param cementCode
	 * @return
	 */
	public String getIntegerYear(String cementCode){
		String[] cementCodes = cementCode.split("-");
		String counts = cementCodes[0];
		return counts;
	}

	/**
	 * Integer补0 转String
	 * @param counts
	 * @return
	 */
	public String getCementCode(Integer counts){
		String tailNo = counts<10?("000"+counts):
				counts<100?("00"+counts):
						counts<1000?("000"+counts):
								String.valueOf(counts);
		return tailNo;
	}


	/**
	 * 保存附件信息
	 * @param entityType  实体类型（0:用户(头像),1:合同附件,3设备校核附件，4标样材料）
	 * @param entityId    关联实体类id
	 * @param enclosureQueryList 上传的附件列表
	 */
	public Boolean saveEntityEnclosure(Integer entityType, Integer entityId, List<EnclosureQuery> enclosureQueryList ){
		Boolean ref = false;
		QueryWrapper<EntityEnclosure> wrapper = new QueryWrapper<>();
		wrapper.eq("entity_type", entityType);
		wrapper.eq("entity_id", entityId);
		List<EntityEnclosure> entityEnclosureList = entityEnclosureMapper.selectList(wrapper);
		if(entityEnclosureList != null && entityEnclosureList.size()>0){
			for(EntityEnclosure eeOld : entityEnclosureList){
				eeOld.setIsDeleted(0);
				entityEnclosureMapper.updateById(eeOld);
			}
		}
		if(enclosureQueryList != null && enclosureQueryList.size()>0){
			List<EntityEnclosure> eeList = new ArrayList<>();
			for(int i = 0; i < enclosureQueryList.size(); i++){
				EnclosureQuery enclosureDto = enclosureQueryList.get(i);
				EntityEnclosure ee = new EntityEnclosure();
				ee.setEntityId(entityId);
				ee.setEntityType(entityType);
				ee.setEnclosureUrl(enclosureDto.getEnclosureUrl());
				ee.setCreateTime(LocalDateTime.now());
				ee.setUpdateTime(ee.getCreateTime());
				ee.setIsDeleted(1);
				ee.setAlias(enclosureDto.getAlias());
				ee.setExtName(enclosureDto.getExtName());
				eeList.add(ee);
			}
			entityEnclosureService.saveBatch(eeList);
		}
		ref = true;
		return ref;
	}

	/**
	 * 根据实体类型 和实体类id获取附件列表
	 * @param entityType  实体类型（0:用户(头像),1:合同附件,3设备校核附件，4标样材料）
	 * @param entityId    关联实体类id
	 * @return
	 */
	public List<EntityEnclosure> getEnclosureList(Integer entityType,  Integer entityId){
		QueryWrapper<EntityEnclosure> wrapper = new QueryWrapper<>();
		wrapper.eq("entity_type", entityType);
		wrapper.eq("entity_id", entityId);
		List<EntityEnclosure> entityEnclosureList = entityEnclosureMapper.selectList(wrapper);
		return entityEnclosureList;
	}






	public Map<String, Object> checkCount(Integer teamGroupId, Map<String, Object> resultMap ){
		List<String> checkResutlList = teamMapper.getByGroup(teamGroupId);
		//100倍
		BigDecimal param100 = new BigDecimal(100.00);
		Map<String, Object> countMap = new HashMap<>();
		for(String name : checkResutlList){
				if(name.equals("L.O.I")){
					countMap.put("L.O.I",CheckCountUtil.checkCount(name,resultMap));
				}else if(name.equals("SiO2")){
					countMap.put("SiO2",CheckCountUtil.checkCount(name,resultMap));
				}

		}

		//合量
		BigDecimal countHL = CheckCountUtil.countHL(countMap);
		countMap.put("合量", countHL);
		//KH
		BigDecimal countKH = CheckCountUtil.countKH(countMap);
		countMap.put("KH", countKH);


		return countMap;
	}


















}
